slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSConv

Determines the convergence test

### Synopsis

    typedef enum { EPS_CONV_ABS,
                   EPS_CONV_REL,
                   EPS_CONV_NORM,
                   EPS_CONV_USER } EPSConv;

### See Also

EPSSetConvergenceTest(), EPSSetConvergenceTestFunction()

### Level

intermediate

### Location

include/slepceps.h
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages